==> 2.1.tar.gz: alice2bob/ja-md/alice2bob-ja-security-plan-2.1.md <==
<img class="top-banner" src="../assets/img/top-banner.png" width="780" height="204" alt="アリスとボブのバナー">

# セキュリティ計画 {#top}

アリスとボブ

バージョン： 2.1

本ガイドの最終更新： 2021-12-29 （原文更新： 2021-02-02）

ガイド一覧に戻る
--- [Markdown](../ja-md/alice2bob-ja-preface-2.1.md#list)
\| [HTML](../ja-html/alice2bob-ja-preface-2.1.html#list)

***

1. [セキュリティ計画](#security-plan)
2. [自分のセキュリティ計画をどうやって？どこから始めるべきか？](#how-to-start)
   1. [守るに値する何を持っているか？](#assets)
   2. [誰または何からそれを守りたいか？](#threats)
   3. [失敗した場合の影響はどれくらい悪いか？](#consequences)
   4. [それを守る必要がある公算はどの程度あるか？](#likelihood)
   5. [可能な影響を防ごうとするためにどれくらい苦労する意志があるか？](#security-cost)
3. [定期的な習慣としてのセキュリティ計画](#regular-practice)

*注：本ガイドは Electronic Frontier Foundation （EFF）
のシリーズ "Surveillance Self-Defense"
のガイド "Your Security Plan" の翻訳です。
原文は以下のリンクでアクセスできます。
`https://ssd.eff.org/en/module/your-security-plan`*

# セキュリティ計画 {#security-plan}

あらゆる人からあらゆる時に自分の全てのデータ[^data]を
保護しようとすることは非現実的で骨が折れるでしょう。
それにしても、恐れないでください！
セキュリティはプロセスで、
思慮に富んだ計画づくりで自分にとって適切な計画を作成できます。
セキュリティは利用するツールやダウンロードするソフトウェア
のことだけではありません。
自分が立ち向かう脅威とその対抗方法の理解で始まります。

コンピュータセキュリティにおいて、
脅威（threat）[^threat]とはデータを守る対策を
弱体化させる恐れがある可能な事象です。
何を誰から守る必要があるかを決意したら、
脅威に対抗できるようになります。
これはセキュリティ計画のプロセスで、
脅威モデル（threat modeling）[^threat-model]と呼ばれます。

本ガイドは、自分のデジタル情報のためのセキュリティ計画を作成して、
どの対策が最適かを決める方法を教えます。

では、セキュリティ計画はどのように見えるか？
自分のお家と所有物を安全にしておきたいとしましょう。
以下の質問を聞くでしょう。

**守るに値する何を持っているか？**

- 財産（asset）[^asset]といえば、
  宝石類、電子製品、金融書類、パスポート、写真など
  を含む可能性があります。

**誰または何からそれを守りたいか？**

- 敵といえば、泥棒、ルームメイト、来客などを含む可能性があります。

**それを守る必要がある公算はどの程度あるか？**

- 近所周辺の泥棒の経歴は？
  ルームメイト・来客はどこまで信用できるか？
  敵の能力はどの程度か？
  考慮すべきリスクは何か？

**失敗した場合の影響はどれくらい悪いか？**

- かけがえのない物は家にあるか？
  守ろうとしている物を取り替える時間やお金があるか？
  家から盗まれた物を補償する保険を持っているか？

**可能な影響を防ごうとするためにどれくらい苦労する意志があるか？**

- センシティブ書類を保管する金庫を買う意志があるか？
  高品質の錠を買う余裕があるか？
  地元の銀行で代金庫を開設して貴重品をそこに保管する時間があるか？

このように自問したら、どの対策を取るかを評価する立場にあるはずです。
所有物が貴重だとしても、侵入の可能性が低い場合、
錠に巨額のお金を投入したくないかもしれません。
一方、侵入の可能性が高い場合、
市販されている最高の錠を買った上で
セキュリティシステムも追加することを考えたいでしょう。

セキュリティ計画を作成することは、
自分に関連する唯一の脅威を理解し、
財産、敵、敵の能力、リスクの発生公算などの
評価を支えてくれます。

# 自分のセキュリティ計画をどうやって？どこから始めるべきか？ {#how-to-start}

セキュリティ計画は、自分が貴重に思う物に対して起こり得ることの特定、
そして誰から保護する必要があるかの決定を支えてくれます。

セキュリティ計画を作成する際、以下の五つの質問を考えましょう。

1. [守るに値する何を持っているか？](#assets)
2. [誰または何からそれを守りたいか？](#threats)
3. [失敗した場合の影響はどれくらい悪いか？](#consequences)
4. [それを守る必要がある公算はどの程度あるか？](#likelihood)
5. [可能な影響を防ごうとするためにどれくらい苦労する意志があるか？](#security-cost)

この質問について詳しく考えましょう。

## 守るに値する何を持っているか？ {#assets}

財産[^asset]とは大切で保護したい物です。
デジタルセキュリティにおいては、財産といえば情報です。
例えば、電子メール、連絡先、メッセージ、位置、ファイルなどは
財産[^asset]でしょう。
デバイスも財産でしょう。

*財産をリストアップしましょう：
保存しているデータ[^data]、保存場所、それにアクセスできる人、
何が他人によるアクセスを防止しているかなど。*

## 誰または何からそれを守りたいか？ {#threats}

この質問を答えるには、
誰が自分または自分の情報を狙うかを特定することが重要です。
自分の財産を脅かす[^threat]人や存在物は
敵（adversary）[^adversary]と呼ばれます。
あり得る敵の例は、上司、元配偶者、商売の競争相手、政府機関、
公共ネットワーク上のハッカーなどです。

**敵、または自分の財産を入手しようとしたいかもしれない人を
リストアップしましょう。
このリストには個人、政府機関、企業などが含まれるかもしれません。**

敵と状況によっては、セキュリティ計画を終えた後、
このリストを破壊した方がいいかもしれません。

## 失敗した場合の影響はどれくらい悪いか？ {#consequences}

敵が自分のデータにアクセスできる手段が様々でしょう。
例えば、敵はネットワーク上の自分のプライベートの通信を
傍受できるかもしれないし、
自分のデータを削除・破損できるかもしれません。

敵の動機は大幅に異なり、方策もそうです。
警察暴力の動画の拡散を止めようとしている政府は
その動画をただ削除するかアクセスを防止することだけで
満足するかもしれません。
それと対照して、ある政治的な相手は秘密の内容へのアクセスを取得し、
その内容を自分が知らずに公開したいかもしれません。

セキュリティ計画は、敵が自分の財産にアクセスするに成功した場合の
悪影響の範囲を理解することを求めます。
これを把握するには、敵の能力[^capability]を考慮すべきです。
例えば、移動体通信提供者は自分の全ての通話記録へのアクセスを持ちます。
誰でも利用できる Wi-Fi ネットワーク上のハッカーは
自分の非暗号化通信を納受できます。
政府機関はより強い能力を有するでしょう。

**敵が自分のプライベートなデータで
何がしたいかもしれないかをリストアップしましょう。**

## それを守る必要がある公算はどの程度あるか？ {#likelihood}

*注：本ガイドの原本は "risk" （リスク）を脅威の発生公算と定義するが、
リスクは脅威の発生公算だけでなく発生後の悪影響も考慮すべき概念です。
影響を無視したら、発生可能性の高い無害のリスクを過大評価する一方、
ありそうにない重大なリスクを過小評価してしまいます。*

リスク（risk）[^risk-assessment]とは、
ある特定の財産に対する特定の脅威が実際に発生する公算です。
敵の能力と強く関連します。
移動体通信提供者が自分の全てのデータにアクセスできるとしても、
そのプライベートのデータをインターネット上に投稿して
自分の評判に害を与える公算が低いでしょう。

起こり得る事象とその事象が起こる公算を区別することは重要です。
例えば、自分の建物が崩壊する脅威はあるが、
（地震がよくある）サンフランシスコで起こるリスクは
（地震がめったにない）ストックホルムより遥かに高いです。

リスクの評価は個人的かつ主観的なプロセスです。
多くの人には、ある脅威が存在するだけで
発生公算を問わず容認できないことがあります。
一方、リスクが高くてもある脅威を問題視しない人もいます。

**どの脅威を重要視し、
どの脅威がありそうにないか無害すぎる（または対抗が無理な）ため
心配するほどではないだろうかをリストアップしましょう。**

## 可能な影響を防ごうとするためにどれくらい苦労する意志があるか？ {#security-cost}

セキュリティには完璧な選択肢はありません。
同じ優先順位、懸念、資源へのアクセスなどを持つ人はいないでしょう。
自分のリスク評価（risk assessment）[^risk-assessment]は、
利便性、コストとプライバシーのバランスを取った
自分にとって適切な戦略を計画できるよう支えてくれます。

例えば、面白い猫の動画をメールで共有する家族のメンバーより、
安全保障の裁判に顧客を代表する弁護士の方が
暗号化メールなどによってその裁判に関連する通信を保護するために
より苦労する意志があるでしょう。

**自分の唯一の脅威を軽減するために
自分が利用できる選択肢をリストアップしましょう。
金銭的な制約、技術的な制約または社会的な制約がある場合、
それも書きましょう。**

# 定期的な習慣としてのセキュリティ計画 {#regular-practice}

セキュリティ計画は状況と共に変わり得ることを念頭に置きましょう。
そのため、セキュリティ計画を頻繁に見直すことは良い習慣です。

自分の状況に基づくセキュリティ計画を作成しましょう。
それから、カレンダー上の将来の日程に印をつけましょう。
これは、計画を見直して自分の状況にまだ適切かを確認するよう
促してくれます。



[^adversary]: 敵（adversary）：
自分のセキュリティ目標を弱体化させようとしている人または組織。
敵は状況によって異なります。
例えば、カフェのネットワークを見張っている犯罪者、
学校の公共コンピュータで自分のアカウントに
不正ログインするかもしれないクラスメートなどが心配かもしれません。
敵はしばしば仮想したものです。

[^asset]: 財産（asset）：
脅威モデルにおいて、保護の対象となるデータやデバイス。

[^capability]: 能力（capability）：
（本ガイドにおける意味合いでの）攻撃者の能力とは、
目標達成のために攻撃者ができること。
例えば、国の安全保障局は通話を傍受する能力を持つかもしれない一方、
隣人は窓から自分を観察する能力を持っているかもしれません。
ある能力を持っているということは、攻撃者がそれを利用するとは限りません。
その可能性と対策を考慮すべきだということです。

[^data]: データ（data）：
典型的にデジタルな形として保存されるあらゆる種類の情報。
データはドキュメント、画像、鍵、プログラム、メッセージや
他のデジタル情報・ファイルを指します。

[^risk-assessment]: リスク評価（risk assessment）：
コンピュータセキュリティにおいて、
脅威から防御するどれくらいの努力をかけるべきかを知るべく、
リスク解析は脅威が発生する確率を計算すること。
データの支配またはアクセスを失う方法は様々かもしれないが、
ある方法は他より可能性が低いでしょう。
リスク評価を行うことは、どの脅威を重要視し、
どの脅威がありそうにないか無害すぎる（または対策が無理な）ため
心配に値しないだろうかを決めることです。
脅威モデルを参照。

[^threat]: 脅威（threat）：
コンピュータセキュリティにおいて、データを守る対策を
弱体化させる恐れがある可能な事象。
脅威といえば、意図的な事象（攻撃者が考案したもの）も
不慮の事象（例：起動したコンピュータを無防備な状態で放置する）
もあります。

[^threat-model]: 脅威モデル（threat model）：
どの可能な脅威を重要視するかを決めるために
どのように自分のデータを保護したいかを考える方法。
あらゆるたくらみや敵から保護することは不可能なため、
どの人が自分のデータを手に入れたいだろうか、何を得たいだろうか、
そしてどのようにそれを得るだろうかに集中すべきです。
防止計画に対象にする可能な脅威のセットを考え出すことは
脅威モデルまたはリスク評価と呼ばれます。


***

# アリスとボブ {#back}

ガイド一覧に戻る
--- [Markdown](../ja-md/alice2bob-ja-preface-2.1.md#list)
\| [HTML](../ja-html/alice2bob-ja-preface-2.1.html#list)

## 連絡先 {#back-contact}

### PGP 鍵 {#back-contact-PGP}

`1D3E 313C 4DB2 B3E0 8271 FC48 89BB 4CBB 9DBE 7F6D`

- ウェブサイト上：
  `https://git.disroot.org/alice2bob/alice2bob/src/branch/master/alice2bob.asc`
- 鍵サーバ（クリアネット）：
  `https://keys.openpgp.org/search?q=1D3E313C4DB2B3E08271FC4889BB4CBB9DBE7F6D`
- 鍵サーバ（オニオン）：
  `http://zkaan2xfbuxia2wpf7ofnkbz6r5zdbbvxbunvp5g2iebopbfc4iqmbad.onion/search?q=1D3E313C4DB2B3E08271FC4889BB4CBB9DBE7F6D`

### ウェブサイト {#back-contact-website}

<img class="qr" src="../assets/qr/contact-website.png" width="222" height="222" alt="ウェブサイト QR コード">

`https://git.disroot.org/alice2bob/alice2bob`

## 検証 {#back-verify}

`https://git.disroot.org/alice2bob/alice2bob/src/branch/master/verify.md`

## 免責事項 {#back-disclaimer}

アリスとボブはセキュリティ専門家でも法律家でも
金融アドバイザーでも医師でもありません。
本シリーズの目的はあくまでも情報提供で、何の助言でもありません。
本シリーズは全くの無保証で提供されます。
本シリーズによってどんな不利、損失または損害が生じても、
アリスとボブは一切の責任を負いません。
ご自身の状況を考慮し、自己責任で本シリーズを使ってください。

==> 2.2.tar.gz: alice2bob/ja-md/alice2bob-ja-security-plan-2.2.md <==
<img class="top-banner" src="../assets/img/top-banner.png" width="780" height="204" alt="アリスとボブのバナー">

# セキュリティ計画 {#top}

アリスとボブ

バージョン： 2.2

本ガイドの最終更新： 2021-12-29 （原文更新： 2021-02-02）

ガイド一覧に戻る
--- [Markdown](../ja-md/alice2bob-ja-preface-2.2.md#list)
\| [HTML](../ja-html/alice2bob-ja-preface-2.2.html#list)

***

1. [セキュリティ計画](#security-plan)
2. [自分のセキュリティ計画をどうやって？どこから始めるべきか？](#how-to-start)
   1. [守るに値する何を持っているか？](#assets)
   2. [誰または何からそれを守りたいか？](#threats)
   3. [失敗した場合の影響はどれくらい悪いか？](#consequences)
   4. [それを守る必要がある公算はどの程度あるか？](#likelihood)
   5. [可能な影響を防ごうとするためにどれくらい苦労する意志があるか？](#security-cost)
3. [定期的な習慣としてのセキュリティ計画](#regular-practice)

*注：本ガイドは Electronic Frontier Foundation （EFF）
のシリーズ "Surveillance Self-Defense"
のガイド "Your Security Plan" の翻訳です。
原文は以下のリンクでアクセスできます。
`https://ssd.eff.org/en/module/your-security-plan`*

# セキュリティ計画 {#security-plan}

あらゆる人からあらゆる時に自分の全てのデータ[^data]を
保護しようとすることは非現実的で骨が折れるでしょう。
それにしても、恐れないでください！
セキュリティはプロセスで、
思慮に富んだ計画づくりで自分にとって適切な計画を作成できます。
セキュリティは利用するツールやダウンロードするソフトウェア
のことだけではありません。
自分が立ち向かう脅威とその対抗方法の理解で始まります。

コンピュータセキュリティにおいて、
**脅威**（threat）[^threat]とは、
データを守る対策を弱体化させる恐れがある可能な事象です。
何を誰から守る必要があるかを決意したら、
脅威に対抗できるようになります。
これはセキュリティ計画のプロセスで、
**脅威モデリング**（threat modeling）[^threat-model]と呼ばれます。

本ガイドは、自分のデジタル情報のためのセキュリティ計画を作成して、
どの対策が最適かを決める方法を教えます。

では、セキュリティ計画はどのように見えるか？
自分のお家と所有物を安全にしておきたいとしましょう。
以下の質問を聞くでしょう。

**守るに値する何を持っているか？**

- **財産**（asset）[^asset]といえば、
  宝石類、電子製品、金融書類、パスポート、写真など
  を含む可能性があります。

**誰または何からそれを守りたいか？**

- **敵**（adversary）[^adversary]といえば、泥棒、ルームメイト、
  来客などを含む可能性があります。

**それを守る必要がある公算はどの程度あるか？**

- 近所周辺の不法侵入の経歴は？
  ルームメイト・来客はどこまで信用できるか？
  敵の**能力**（capability）[^capability]はどの程度か？
  考慮すべきリスクは何か？

**失敗した場合の影響はどれくらい悪いか？**

- かけがえのない物は家にあるか？
  守ろうとしている物を取り替える時間やお金があるか？
  家から盗まれた物を補償する保険を持っているか？

**可能な影響を防ごうとするためにどれくらい苦労する意志があるか？**

- センシティブ書類を保管する金庫を買う意志があるか？
  高品質の錠を買う余裕があるか？
  地元の銀行で代金庫を開設して貴重品をそこに保管する時間があるか？

このように自問したら、どの対策を取るかを評価する立場にあるはずです。
所有物が貴重だとしても、侵入の可能性が低い場合、
錠に巨額のお金を投入したくないかもしれません。
一方、侵入の可能性が高い場合、
市販されている最高の錠を買った上で
セキュリティシステムも追加することを考えたいでしょう。

セキュリティ計画を作成することは、
自分に関連する唯一の脅威を理解し、
財産、敵、敵の能力、リスクの発生公算などの
評価を支えてくれます。

# 自分のセキュリティ計画をどうやって？どこから始めるべきか？ {#how-to-start}

セキュリティ計画は、自分が貴重に思う物に対して起こり得ることの特定、
そして誰から保護する必要があるかの決定を支えてくれます。

セキュリティ計画を作成する際、以下の五つの質問を考えましょう。

1. [守るに値する何を持っているか？](#assets)
2. [誰または何からそれを守りたいか？](#threats)
3. [失敗した場合の影響はどれくらい悪いか？](#consequences)
4. [それを守る必要がある公算はどの程度あるか？](#likelihood)
5. [可能な影響を防ごうとするためにどれくらい苦労する意志があるか？](#security-cost)

この質問について詳しく考えましょう。

## 守るに値する何を持っているか？ {#assets}

財産[^asset]とは、大切で保護したい物です。
デジタルセキュリティにおいては、財産といえば情報です。
例えば、電子メール、連絡先、メッセージ、位置、ファイルなどは
財産[^asset]でしょう。
デバイスも財産でしょう。

財産をリストアップしましょう：
保存しているデータ[^data]、保存場所、それにアクセスできる人、
何が他人によるアクセスを防止しているかなど。

## 誰または何からそれを守りたいか？ {#threats}

この質問を答えるには、
誰が自分または自分の情報を狙うかを特定することが重要です。
自分の財産を脅かす[^threat]人や存在物は
敵[^adversary]と呼ばれます。
あり得る敵の例は、上司、元配偶者、商売の競争相手、政府機関、
公共ネットワーク上のハッカーなどです。

敵、または自分の財産を入手しようとしたいかもしれない人を
リストアップしましょう。
このリストには個人、政府機関、企業などが含まれるかもしれません。

敵と状況によっては、セキュリティ計画を終えた後、
このリストを破壊した方がいいかもしれません。

## 失敗した場合の影響はどれくらい悪いか？ {#consequences}

敵が自分のデータにアクセスできる手段が様々でしょう。
例えば、敵はネットワーク上の自分のプライベートの通信を
傍受できるかもしれないし、
自分のデータを削除・破損できるかもしれません。

敵の動機は大幅に異なり、方策もそうです。
警察暴力の動画の拡散を止めようとしている政府は
その動画をただ削除するかアクセスを防止することだけで
満足するかもしれません。
それと対照して、ある政治的な相手は秘密の内容へのアクセスを取得し、
その内容を自分が知らずに公開したいかもしれません。

セキュリティ計画は、敵が自分の財産にアクセスするに成功した場合の
悪影響の範囲を理解することを求めます。
これを把握するには、敵の能力[^capability]を考慮すべきです。
例えば、移動体通信提供者は自分の全ての通話記録へのアクセスを持ちます。
誰でも利用できる Wi-Fi ネットワーク上のハッカーは
自分の非暗号化通信を納受できます。
政府機関はより強い能力を有するでしょう。

敵が自分のプライベートなデータで
何がしたいかもしれないかをリストアップしましょう。

## それを守る必要がある公算はどの程度あるか？ {#likelihood}

*注：本ガイドの原本は "risk" （リスク）を脅威の発生公算と定義するが、
リスクは脅威の発生公算だけでなく発生後の悪影響も考慮すべき概念です。
影響を無視したら、発生可能性の高い無害のリスクを過大評価する一方、
ありそうにない重大なリスクを過小評価してしまいます。*

**リスク**（risk）[^risk-assessment]とは、
ある特定の財産に対する特定の脅威が実際に発生する公算です。
敵の能力と強く関連します。
移動体通信提供者が自分の全てのデータにアクセスできるとしても、
そのプライベートのデータをインターネット上に投稿して
自分の評判に害を与える公算が低いでしょう。

起こり得る事象とその事象が起こる公算を区別することは重要です。
例えば、自分の建物が崩壊する脅威はあるが、
（地震がよくある）サンフランシスコで起こるリスクは
（地震がめったにない）ストックホルムより遥かに高いです。

リスクの評価は個人的かつ主観的なプロセスです。
多くの人には、ある脅威が存在するだけで
発生公算を問わず容認できないことがあります。
一方、リスクが高くてもある脅威を問題視しない人もいます。

どの脅威を重要視し、
どの脅威がありそうにないか無害すぎる（または対抗が無理な）ため
心配するほどではないだろうかをリストアップしましょう。

## 可能な影響を防ごうとするためにどれくらい苦労する意志があるか？ {#security-cost}

セキュリティには完璧な選択肢はありません。
同じ優先順位、懸念、資源へのアクセスなどを持つ人はいないでしょう。
自分の**リスク評価**（risk assessment）[^risk-assessment]は、
利便性、コストとプライバシーのバランスを取った
自分にとって適切な戦略を計画できるよう支えてくれます。

例えば、面白い猫の動画をメールで共有する家族のメンバーより、
安全保障の裁判に顧客を代表する弁護士の方が
暗号化メールなどによってその裁判に関連する通信を保護するために
より苦労する意志があるでしょう。

自分の唯一の脅威を軽減するために
自分が利用できる選択肢をリストアップしましょう。
金銭的な制約、技術的な制約または社会的な制約がある場合、
それも書きましょう。

# 定期的な習慣としてのセキュリティ計画 {#regular-practice}

セキュリティ計画は状況と共に変わり得ることを念頭に置きましょう。
そのため、セキュリティ計画を頻繁に見直すことは良い習慣です。

自分の状況に基づくセキュリティ計画を作成しましょう。
それから、カレンダー上の将来の日程に印をつけましょう。
これは、計画を見直して自分の状況にまだ適切かを確認するよう
促してくれます。



[^adversary]: 敵（adversary）：
自分のセキュリティ目標を弱体化させようとしている人または組織。
敵は状況によって異なります。
例えば、カフェのネットワークを見張っている犯罪者、
学校の公共コンピュータで自分のアカウントに
不正ログインするかもしれないクラスメートなどが心配かもしれません。
敵はしばしば仮想したものです。

[^asset]: 財産（asset）：
脅威モデルにおいて、保護の対象となるデータやデバイス。

[^capability]: 能力（capability）：
（本ガイドにおける意味合いでの）攻撃者の能力とは、
目標達成のために攻撃者ができること。
例えば、国の安全保障局は通話を傍受する能力を持つかもしれない一方、
隣人は窓から自分を観察する能力を持っているかもしれません。
ある能力を持っているということは、攻撃者がそれを利用するとは限りません。
その可能性と対策を考慮すべきだということです。

[^data]: データ（data）：
典型的にデジタルな形として保存されるあらゆる種類の情報。
データはドキュメント、画像、鍵、プログラム、メッセージや
他のデジタル情報・ファイルを指します。

[^risk-assessment]: リスク評価（risk assessment）：
コンピュータセキュリティにおいて、
脅威から防御するどれくらいの努力をかけるべきかを知るべく、
リスク解析は脅威が発生する確率を計算すること。
データの支配またはアクセスを失う方法は様々かもしれないが、
ある方法は他より可能性が低いでしょう。
リスク評価を行うことは、どの脅威を重要視し、
どの脅威がありそうにないか無害すぎる（または対策が無理な）ため
心配に値しないだろうかを決めることです。
脅威モデリングを参照。

[^threat]: 脅威（threat）：
コンピュータセキュリティにおいて、データを守る対策を
弱体化させる恐れがある可能な事象。
脅威といえば、意図的な事象（攻撃者が考案したもの）も
不慮の事象（例：起動したコンピュータを無防備な状態で放置する）
もあります。

[^threat-model]: 脅威モデル（threat model）：
どの可能な脅威を重要視するかを決めるために
どのように自分のデータを保護したいかを考える方法。
あらゆるたくらみや敵から保護することは不可能なため、
どの人が自分のデータを手に入れたいだろうか、何を得たいだろうか、
そしてどのようにそれを得るだろうかに集中すべきです。
防止計画に対象にする可能な脅威のセットを考え出すことは
脅威モデリングまたはリスク評価と呼ばれます。


***

# アリスとボブ {#back}

ガイド一覧に戻る
--- [Markdown](../ja-md/alice2bob-ja-preface-2.2.md#list)
\| [HTML](../ja-html/alice2bob-ja-preface-2.2.html#list)

## 連絡先 {#back-contact}

### PGP 鍵 {#back-contact-PGP}

`1D3E 313C 4DB2 B3E0 8271 FC48 89BB 4CBB 9DBE 7F6D`

- ウェブサイト上：
  `https://git.disroot.org/alice2bob/alice2bob/src/branch/master/alice2bob.asc`
- 鍵サーバ（クリアネット）：
  `https://keys.openpgp.org/search?q=1D3E313C4DB2B3E08271FC4889BB4CBB9DBE7F6D`
- 鍵サーバ（オニオン）：
  `http://zkaan2xfbuxia2wpf7ofnkbz6r5zdbbvxbunvp5g2iebopbfc4iqmbad.onion/search?q=1D3E313C4DB2B3E08271FC4889BB4CBB9DBE7F6D`

### ウェブサイト {#back-contact-website}

<img class="qr" src="../assets/qr/contact-website.png" width="222" height="222" alt="ウェブサイト QR コード">

`https://git.disroot.org/alice2bob/alice2bob`

## 検証 {#back-verify}

`https://git.disroot.org/alice2bob/alice2bob/src/branch/master/verify.md`

## 免責事項 {#back-disclaimer}

アリスとボブはセキュリティ専門家でも法律家でも
金融アドバイザーでも医師でもありません。
本シリーズの目的はあくまでも情報提供で、何の助言でもありません。
本シリーズは全くの無保証で提供されます。
本シリーズによってどんな不利、損失または損害が生じても、
アリスとボブは一切の責任を負いません。
ご自身の状況を考慮し、自己責任で本シリーズを使ってください。
